summaryrefslogtreecommitdiff
path: root/tests/system
diff options
context:
space:
mode:
authorChristian Stenger <christian.stenger@qt.io>2020-01-27 14:48:58 +0100
committerChristian Stenger <christian.stenger@qt.io>2020-01-29 06:12:29 +0000
commit9a1135776d8ec3e5cf13636a899d9df4daaf8a38 (patch)
tree93145148ca8914afee9a4d61356af9a45d659723 /tests/system
parent3fe997566419b9df00e7a755eefec180e5bcabe4 (diff)
downloadqt-creator-9a1135776d8ec3e5cf13636a899d9df4daaf8a38.tar.gz
Squish: Adapt to changed build menu entries
Change-Id: I0b9ceb8024e42960a2b915ed5e59ae5d33fa4207 Reviewed-by: Robert Loehning <robert.loehning@qt.io>
Diffstat (limited to 'tests/system')
-rwxr-xr-xtests/system/suite_CCOM/tst_CCOM01/test.py2
-rw-r--r--tests/system/suite_debugger/tst_simple_analyze/test.py6
-rw-r--r--tests/system/suite_debugger/tst_simple_debug/test.py2
-rw-r--r--tests/system/suite_general/tst_build_speedcrunch/test.py2
-rw-r--r--tests/system/suite_general/tst_cmake_speedcrunch/test.py2
-rw-r--r--tests/system/suite_qtquick/tst_qtquick_creation/test.py2
-rw-r--r--tests/system/suite_qtquick/tst_qtquick_creation4/test.py2
-rw-r--r--tests/system/suite_tools/tst_designer_edit/test.py2
8 files changed, 10 insertions, 10 deletions
diff --git a/tests/system/suite_CCOM/tst_CCOM01/test.py b/tests/system/suite_CCOM/tst_CCOM01/test.py
index 8a512c87df..516f9fd5b2 100755
--- a/tests/system/suite_CCOM/tst_CCOM01/test.py
+++ b/tests/system/suite_CCOM/tst_CCOM01/test.py
@@ -51,7 +51,7 @@ def main():
selectBuildConfig(kit, config)
# try to build project
test.log("Testing build configuration: " + config)
- invokeMenuItem("Build", "Build All")
+ invokeMenuItem("Build", "Build All Projects")
waitForCompile()
# verify build successful
ensureChecked(waitForObject(":Qt Creator_CompileOutput_Core::Internal::OutputPaneToggleButton"))
diff --git a/tests/system/suite_debugger/tst_simple_debug/test.py b/tests/system/suite_debugger/tst_simple_debug/test.py
index 2d94110c41..7d5f598336 100644
--- a/tests/system/suite_debugger/tst_simple_debug/test.py
+++ b/tests/system/suite_debugger/tst_simple_debug/test.py
@@ -60,7 +60,7 @@ def main():
test.log("Selecting '%s' as build config" % config)
verifyBuildConfig(kit, config, True, True, True)
# explicitly build before start debugging for adding the executable as allowed program to WinFW
- invokeMenuItem("Build", "Rebuild All")
+ invokeMenuItem("Build", "Rebuild All Projects")
waitForCompile(300000)
if not checkCompile():
test.fatal("Compile had errors... Skipping current build config")
diff --git a/tests/system/suite_general/tst_build_speedcrunch/test.py b/tests/system/suite_general/tst_build_speedcrunch/test.py
index e3543d55fa..5160d7c7ca 100644
--- a/tests/system/suite_general/tst_build_speedcrunch/test.py
+++ b/tests/system/suite_general/tst_build_speedcrunch/test.py
@@ -58,7 +58,7 @@ def main():
test.log("Testing build configuration: " + config)
invokeMenuItem("Build", "Run qmake")
waitForCompile()
- invokeMenuItem("Build", "Rebuild All")
+ invokeMenuItem("Build", "Rebuild All Projects")
waitForCompile(300000)
checkCompile()
checkLastBuild()
diff --git a/tests/system/suite_general/tst_cmake_speedcrunch/test.py b/tests/system/suite_general/tst_cmake_speedcrunch/test.py
index 2d9a3e2def..29a7934a7f 100644
--- a/tests/system/suite_general/tst_cmake_speedcrunch/test.py
+++ b/tests/system/suite_general/tst_cmake_speedcrunch/test.py
@@ -69,7 +69,7 @@ def main():
compareProjectTree(naviTreeView % "speedcrunch( \[\S+\])?", treeFile)
# Invoke a rebuild of the application
- invokeMenuItem("Build", "Rebuild All")
+ invokeMenuItem("Build", "Rebuild All Projects")
# Wait for, and test if the build succeeded
waitForCompile(300000)
diff --git a/tests/system/suite_qtquick/tst_qtquick_creation/test.py b/tests/system/suite_qtquick/tst_qtquick_creation/test.py
index d4bb433896..d27b7fa9c0 100644
--- a/tests/system/suite_qtquick/tst_qtquick_creation/test.py
+++ b/tests/system/suite_qtquick/tst_qtquick_creation/test.py
@@ -44,7 +44,7 @@ def main():
continue
test.log("Building project %s (%s)"
% (appTemplate, Targets.getStringForTarget(targ)))
- invokeMenuItem("Build", "Build All")
+ invokeMenuItem("Build", "Build All Projects")
waitForCompile()
if not checkCompile():
test.fatal("Compile failed")
diff --git a/tests/system/suite_qtquick/tst_qtquick_creation4/test.py b/tests/system/suite_qtquick/tst_qtquick_creation4/test.py
index c1e5105ba1..630cb35bae 100644
--- a/tests/system/suite_qtquick/tst_qtquick_creation4/test.py
+++ b/tests/system/suite_qtquick/tst_qtquick_creation4/test.py
@@ -36,7 +36,7 @@ def main():
waitForProjectParsing()
test.log("Building project Qt Quick 2 Extension Plugin (%s)"
% Targets.getStringForTarget(target))
- invokeMenuItem("Build","Build All")
+ invokeMenuItem("Build","Build All Projects")
waitForCompile()
checkCompile()
checkLastBuild()
diff --git a/tests/system/suite_tools/tst_designer_edit/test.py b/tests/system/suite_tools/tst_designer_edit/test.py
index 8790ff84e1..b3d264466e 100644
--- a/tests/system/suite_tools/tst_designer_edit/test.py
+++ b/tests/system/suite_tools/tst_designer_edit/test.py
@@ -201,7 +201,7 @@ def main():
comboItems = performEditCombo()
verifyPreview(menuItems, comboItems)
invokeMenuItem("File", "Save All")
- invokeMenuItem("Build", "Build All")
+ invokeMenuItem("Build", "Build All Projects")
waitForCompile()
checkCompile()
invokeMenuItem("File", "Exit")
diff --git a/tests/system/suite_debugger/tst_simple_analyze/test.py b/tests/system/suite_debugger/tst_simple_analyze/test.py
index 111336e33a..6c694f063e 100644
--- a/tests/system/suite_debugger/tst_simple_analyze/test.py
+++ b/tests/system/suite_debugger/tst_simple_analyze/test.py
@@ -62,14 +62,14 @@ def performTest(workingDir, projectName, availableConfigs):
return float(re.search("Elapsed:\s+(-?\d+\.\d+) s", elapsedTimeLabelText).group(1))
for kit, config in availableConfigs:
# switching from MSVC to MinGW build will fail on the clean step of 'Rebuild All' because
# of differences between MSVC's and MinGW's Makefile (so clean before switching kits)
invokeMenuItem('Build', 'Clean Project "%s"' % projectName)
verifyBuildConfig(kit, config, True, True, True)
qtVersion = "5.6.1" if kit == Targets.DESKTOP_5_6_1_DEFAULT else "5.10.1"
test.log("Selected kit using Qt %s" % qtVersion)
# explicitly build before start debugging for adding the executable as allowed program to WinFW
- invokeMenuItem("Build", "Rebuild All")
+ invokeMenuItem("Build", "Rebuild All Projects")
waitForCompile()
if not checkCompile():
test.fatal("Compile had errors... Skipping current build config")
@@ -62,14 +62,14 @@ def performTest(workingDir, projectName, availableConfigs):
return float(re.search("Elapsed:\s+(-?\d+\.\d+) s", elapsedTimeLabelText).group(1))
for kit, config in availableConfigs:
- # switching from MSVC to MinGW build will fail on the clean step of 'Rebuild All' because
- # of differences between MSVC's and MinGW's Makefile (so clean before switching kits)
+ # switching from MSVC to MinGW build will fail on the clean step of 'Rebuild All Projects'
+ # because of differences between MSVC's and MinGW's Makefile (so clean before changing kit)
invokeMenuItem('Build', 'Clean Project "%s"' % projectName)
verifyBuildConfig(kit, config, True, True, True)